"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.BaseValidator = void 0;
const tslib_1 = require("tslib");
const lodash_1 = tslib_1.__importDefault(require("lodash"));
class BaseValidator {
    constructor(validator) {
        this.validator = validator;
    }
    get ids() {
        const ids = [this.getId()];
        if (this.validator)
            ids.unshift(...this.validator.ids);
        return ids;
    }
    validate(template) {
        const prevErrors = this.validator ? this.validator.validate(template) : [];
        const validators = this.getValidators();
        const { error } = validators.validate(template, { abortEarly: false });
        const errors = error
            ? error.details.map((error) => lodash_1.default.pick(error, ["type", "path", "message"]))
            : [];
        return [...prevErrors, ...errors];
    }
    getComponents(template) {
        return this.validator ? this.validator.getComponents(template) : {};
    }
}
exports.BaseValidator = BaseValidator;
